#ifndef __tga_h
#define __tga_h
int LoadTGATexture(Texture * texture, char *filename)
{

	// Targa data type -- uncompressed, RGBA image; element 
	// 3 is always 2. 
	GLubyte targaMagic[12] = {
		0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0
	};
	GLubyte fileMagic[12];

	// Header data. 
	GLubyte header[6];
	GLuint bytesPerPixel;
	int imageSize;
	GLuint tmp;
	GLuint i;
	FILE *file;
	fprintf(stderr, "                     Open texture file\n");
	fflush(NULL);
	if ((file = fopen(filename, "rb")) == NULL)
	{
		return 1;
	}
	// Start reading in the header, make sure we 
	// have the right Targa data type.   
	if (file == NULL
	    || fread(fileMagic, 1, sizeof(fileMagic), file) != sizeof(fileMagic)
	    || memcmp(targaMagic, fileMagic, sizeof(targaMagic)) != 0
	    || fread(header, 1, sizeof(header), file) != sizeof(header))

	{
		fclose(file);
		return 1;
	}
	// Determine width and height from header data. 
	fprintf(stderr, "			Get texture dimensions\n");
	fflush(NULL);
	texture->width = header[1] * 256 + header[0];
	texture->height = header[3] * 256 + header[2];
	texture->truewidth = texture->width;
	texture->trueheight = texture->height;

	// Determine color bit depth of the image (24 or 32). 
	fprintf(stderr, "			get colour depth\n");
	fflush(NULL);
	if (texture->width <= 0 || texture->height <= 0 || (header[4] != 24 && header[4] != 32))

	{
		fclose(file);
		return 1;
	}
	fprintf(stderr, "			set up texture\n");
	fflush(NULL);
	texture->bpp = header[4];
	bytesPerPixel = texture->bpp / 8;
	texture->channels = bytesPerPixel;
	imageSize = texture->width * texture->height * bytesPerPixel;
	texture->aspectratio = ((float)texture->width) / ((float)texture->height);
	fprintf(stderr, "			callocing data\n");
	fflush(NULL);
	texture->imageData = (GLubyte *) mem_calloc((size_t) imageSize);
	fprintf(stderr, "			Loading image data\n");
	fflush(NULL);
	if (texture->imageData == NULL || fread(texture->imageData, 1, imageSize, file) != imageSize)

	{
		if (texture->imageData != NULL)
			mem_free(texture->imageData);
		fclose(file);
		return 1;
	}
	fprintf(stderr, "			Reversing BGR\n");
	fflush(NULL);
	for (i = 0; i < imageSize; i += bytesPerPixel)

	{
		tmp = texture->imageData[i];
		texture->imageData[i] = texture->imageData[i + 2];
		texture->imageData[i + 2] = tmp;
	}
	fprintf(stderr, "			Finished with texture\n");
	fflush(NULL);
	fclose(file);
	return 0;
}

#endif				/*   */
